@@ -20,7 +20,6 @@ distributed data.
 Chen et al., IEEE Trans. on Sign. Proc., Volume 58, Issue 10, October 2010.
 
 """
-print(__doc__)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -44,8 +43,7 @@ lw_shrinkage = np.zeros((n_samples_range.size, repeat))
 oa_shrinkage = np.zeros((n_samples_range.size, repeat))
 for i, n_samples in enumerate(n_samples_range):
     for j in range(repeat):
-        X = np.dot(
-            np.random.normal(size=(n_samples, n_features)), coloring_matrix.T)
+        X = np.dot(np.random.normal(size=(n_samples, n_features)), coloring_matrix.T)
 
         lw = LedoitWolf(store_precision=False, assume_centered=True)
         lw.fit(X)
@@ -59,10 +57,22 @@ for i, n_samples in enumerate(n_samples_range):
 
 # plot MSE
 plt.subplot(2, 1, 1)
-plt.errorbar(n_samples_range, lw_mse.mean(1), yerr=lw_mse.std(1),
-             label='Ledoit-Wolf', color='navy', lw=2)
-plt.errorbar(n_samples_range, oa_mse.mean(1), yerr=oa_mse.std(1),
-             label='OAS', color='darkorange', lw=2)
+plt.errorbar(
+    n_samples_range,
+    lw_mse.mean(1),
+    yerr=lw_mse.std(1),
+    label="Ledoit-Wolf",
+    color="navy",
+    lw=2,
+)
+plt.errorbar(
+    n_samples_range,
+    oa_mse.mean(1),
+    yerr=oa_mse.std(1),
+    label="OAS",
+    color="darkorange",
+    lw=2,
+)
 plt.ylabel("Squared error")
 plt.legend(loc="upper right")
 plt.title("Comparison of covariance estimators")
@@ -70,14 +80,26 @@ plt.xlim(5, 31)
 
 # plot shrinkage coefficient
 plt.subplot(2, 1, 2)
-plt.errorbar(n_samples_range, lw_shrinkage.mean(1), yerr=lw_shrinkage.std(1),
-             label='Ledoit-Wolf', color='navy', lw=2)
-plt.errorbar(n_samples_range, oa_shrinkage.mean(1), yerr=oa_shrinkage.std(1),
-             label='OAS', color='darkorange', lw=2)
+plt.errorbar(
+    n_samples_range,
+    lw_shrinkage.mean(1),
+    yerr=lw_shrinkage.std(1),
+    label="Ledoit-Wolf",
+    color="navy",
+    lw=2,
+)
+plt.errorbar(
+    n_samples_range,
+    oa_shrinkage.mean(1),
+    yerr=oa_shrinkage.std(1),
+    label="OAS",
+    color="darkorange",
+    lw=2,
+)
 plt.xlabel("n_samples")
 plt.ylabel("Shrinkage")
 plt.legend(loc="lower right")
-plt.ylim(plt.ylim()[0], 1. + (plt.ylim()[1] - plt.ylim()[0]) / 10.)
+plt.ylim(plt.ylim()[0], 1.0 + (plt.ylim()[1] - plt.ylim()[0]) / 10.0)
 plt.xlim(5, 31)
 
 plt.show()
