@@ -18,7 +18,6 @@ whereas real SAMME.R uses the predicted class probabilities.
 .. [2] J. Zhu, H. Zou, S. Rosset, T. Hastie, "Multi-class AdaBoost", 2009.
 
 """
-print(__doc__)
 
 # Author: Peter Prettenhofer <peter.prettenhofer@gmail.com>,
 #         Noel Dawe <noel.dawe@gmail.com>
@@ -36,7 +35,7 @@ from sklearn.ensemble import AdaBoostClassifier
 
 n_estimators = 400
 # A learning rate of 1. may not be optimal for both SAMME and SAMME.R
-learning_rate = 1.
+learning_rate = 1.0
 
 X, y = datasets.make_hastie_10_2(n_samples=12000, random_state=1)
 
@@ -55,23 +54,23 @@ ada_discrete = AdaBoostClassifier(
     base_estimator=dt_stump,
     learning_rate=learning_rate,
     n_estimators=n_estimators,
-    algorithm="SAMME")
+    algorithm="SAMME",
+)
 ada_discrete.fit(X_train, y_train)
 
 ada_real = AdaBoostClassifier(
     base_estimator=dt_stump,
     learning_rate=learning_rate,
     n_estimators=n_estimators,
-    algorithm="SAMME.R")
+    algorithm="SAMME.R",
+)
 ada_real.fit(X_train, y_train)
 
 fig = plt.figure()
 ax = fig.add_subplot(111)
 
-ax.plot([1, n_estimators], [dt_stump_err] * 2, 'k-',
-        label='Decision Stump Error')
-ax.plot([1, n_estimators], [dt_err] * 2, 'k--',
-        label='Decision Tree Error')
+ax.plot([1, n_estimators], [dt_stump_err] * 2, "k-", label="Decision Stump Error")
+ax.plot([1, n_estimators], [dt_err] * 2, "k--", label="Decision Tree Error")
 
 ada_discrete_err = np.zeros((n_estimators,))
 for i, y_pred in enumerate(ada_discrete.staged_predict(X_test)):
@@ -89,24 +88,36 @@ ada_real_err_train = np.zeros((n_estimators,))
 for i, y_pred in enumerate(ada_real.staged_predict(X_train)):
     ada_real_err_train[i] = zero_one_loss(y_pred, y_train)
 
-ax.plot(np.arange(n_estimators) + 1, ada_discrete_err,
-        label='Discrete AdaBoost Test Error',
-        color='red')
-ax.plot(np.arange(n_estimators) + 1, ada_discrete_err_train,
-        label='Discrete AdaBoost Train Error',
-        color='blue')
-ax.plot(np.arange(n_estimators) + 1, ada_real_err,
-        label='Real AdaBoost Test Error',
-        color='orange')
-ax.plot(np.arange(n_estimators) + 1, ada_real_err_train,
-        label='Real AdaBoost Train Error',
-        color='green')
+ax.plot(
+    np.arange(n_estimators) + 1,
+    ada_discrete_err,
+    label="Discrete AdaBoost Test Error",
+    color="red",
+)
+ax.plot(
+    np.arange(n_estimators) + 1,
+    ada_discrete_err_train,
+    label="Discrete AdaBoost Train Error",
+    color="blue",
+)
+ax.plot(
+    np.arange(n_estimators) + 1,
+    ada_real_err,
+    label="Real AdaBoost Test Error",
+    color="orange",
+)
+ax.plot(
+    np.arange(n_estimators) + 1,
+    ada_real_err_train,
+    label="Real AdaBoost Train Error",
+    color="green",
+)
 
 ax.set_ylim((0.0, 0.5))
-ax.set_xlabel('n_estimators')
-ax.set_ylabel('error rate')
+ax.set_xlabel("n_estimators")
+ax.set_ylabel("error rate")
 
-leg = ax.legend(loc='upper right', fancybox=True)
+leg = ax.legend(loc="upper right", fancybox=True)
 leg.get_frame().set_alpha(0.7)
 
 plt.show()
