@@ -20,11 +20,11 @@ can mitigate those limitations.
 
 .. topic:: References:
 
-   [1] L. Breiman, "Random Forests", Machine Learning, 45(1), 5-32,
-       2001. https://doi.org/10.1023/A:1010933404324
+   * :doi:`L. Breiman, "Random Forests", Machine Learning, 45(1), 5-32,
+     2001. <10.1023/A:1010933404324>`
 
 """
-
+# %%
 import matplotlib.pyplot as plt
 import numpy as np
 
