@@ -18,160 +18,20 @@ from ..base import BaseEstimator, TransformerMixin
 
 from ..utils.sparsefuncs import min_max_axis
 from ..utils import column_or_1d
-from ..utils.validation import check_array
-from ..utils.validation import check_is_fitted
-from ..utils.validation import _num_samples
-from ..utils.validation import _deprecate_positional_args
+from ..utils.validation import _num_samples, check_array, check_is_fitted
 from ..utils.multiclass import unique_labels
 from ..utils.multiclass import type_of_target
+from ..utils._encode import _encode, _unique
 
 
 __all__ = [
-    'label_binarize',
-    'LabelBinarizer',
-    'LabelEncoder',
-    'MultiLabelBinarizer',
+    "label_binarize",
+    "LabelBinarizer",
+    "LabelEncoder",
+    "MultiLabelBinarizer",
 ]
 
 
-def _encode_numpy(values, uniques=None, encode=False, check_unknown=True):
-    # only used in _encode below, see docstring there for details
-    if uniques is None:
-        if encode:
-            uniques, encoded = np.unique(values, return_inverse=True)
-            return uniques, encoded
-        else:
-            # unique sorts
-            return np.unique(values)
-    if encode:
-        if check_unknown:
-            diff = _encode_check_unknown(values, uniques)
-            if diff:
-                raise ValueError("y contains previously unseen labels: %s"
-                                 % str(diff))
-        encoded = np.searchsorted(uniques, values)
-        return uniques, encoded
-    else:
-        return uniques
-
-
-def _encode_python(values, uniques=None, encode=False):
-    # only used in _encode below, see docstring there for details
-    if uniques is None:
-        uniques = sorted(set(values))
-        uniques = np.array(uniques, dtype=values.dtype)
-    if encode:
-        table = {val: i for i, val in enumerate(uniques)}
-        try:
-            encoded = np.array([table[v] for v in values])
-        except KeyError as e:
-            raise ValueError("y contains previously unseen labels: %s"
-                             % str(e))
-        return uniques, encoded
-    else:
-        return uniques
-
-
-def _encode(values, uniques=None, encode=False, check_unknown=True):
-    """Helper function to factorize (find uniques) and encode values.
-
-    Uses pure python method for object dtype, and numpy method for
-    all other dtypes.
-    The numpy method has the limitation that the `uniques` need to
-    be sorted. Importantly, this is not checked but assumed to already be
-    the case. The calling method needs to ensure this for all non-object
-    values.
-
-    Parameters
-    ----------
-    values : array
-        Values to factorize or encode.
-    uniques : array, optional
-        If passed, uniques are not determined from passed values (this
-        can be because the user specified categories, or because they
-        already have been determined in fit).
-    encode : bool, default False
-        If True, also encode the values into integer codes based on `uniques`.
-    check_unknown : bool, default True
-        If True, check for values in ``values`` that are not in ``unique``
-        and raise an error. This is ignored for object dtype, and treated as
-        True in this case. This parameter is useful for
-        _BaseEncoder._transform() to avoid calling _encode_check_unknown()
-        twice.
-
-    Returns
-    -------
-    uniques
-        If ``encode=False``. The unique values are sorted if the `uniques`
-        parameter was None (and thus inferred from the data).
-    (uniques, encoded)
-        If ``encode=True``.
-
-    """
-    if values.dtype == object:
-        try:
-            res = _encode_python(values, uniques, encode)
-        except TypeError:
-            types = sorted(t.__qualname__
-                           for t in set(type(v) for v in values))
-            raise TypeError("Encoders require their input to be uniformly "
-                            f"strings or numbers. Got {types}")
-        return res
-    else:
-        return _encode_numpy(values, uniques, encode,
-                             check_unknown=check_unknown)
-
-
-def _encode_check_unknown(values, uniques, return_mask=False):
-    """
-    Helper function to check for unknowns in values to be encoded.
-
-    Uses pure python method for object dtype, and numpy method for
-    all other dtypes.
-
-    Parameters
-    ----------
-    values : array
-        Values to check for unknowns.
-    uniques : array
-        Allowed uniques values.
-    return_mask : bool, default False
-        If True, return a mask of the same shape as `values` indicating
-        the valid values.
-
-    Returns
-    -------
-    diff : list
-        The unique values present in `values` and not in `uniques` (the
-        unknown values).
-    valid_mask : boolean array
-        Additionally returned if ``return_mask=True``.
-
-    """
-    if values.dtype == object:
-        uniques_set = set(uniques)
-        diff = list(set(values) - uniques_set)
-        if return_mask:
-            if diff:
-                valid_mask = np.array([val in uniques_set for val in values])
-            else:
-                valid_mask = np.ones(len(values), dtype=bool)
-            return diff, valid_mask
-        else:
-            return diff
-    else:
-        unique_values = np.unique(values)
-        diff = list(np.setdiff1d(unique_values, uniques, assume_unique=True))
-        if return_mask:
-            if diff:
-                valid_mask = np.in1d(values, uniques)
-            else:
-                valid_mask = np.ones(len(values), dtype=bool)
-            return diff, valid_mask
-        else:
-            return diff
-
-
 class LabelEncoder(TransformerMixin, BaseEstimator):
     """Encode target labels with value between 0 and n_classes-1.
 
@@ -184,9 +44,15 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
 
     Attributes
     ----------
-    classes_ : array of shape (n_class,)
+    classes_ : ndarray of shape (n_classes,)
         Holds the label for each class.
 
+    See Also
+    --------
+    OrdinalEncoder : Encode categorical features using an ordinal encoding
+        scheme.
+    OneHotEncoder : Encode categorical features as a one-hot numeric array.
+
     Examples
     --------
     `LabelEncoder` can be used to normalize labels.
@@ -214,18 +80,10 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
     array([2, 2, 1]...)
     >>> list(le.inverse_transform([2, 2, 1]))
     ['tokyo', 'tokyo', 'paris']
-
-    See also
-    --------
-    sklearn.preprocessing.OrdinalEncoder : Encode categorical features
-        using an ordinal encoding scheme.
-
-    sklearn.preprocessing.OneHotEncoder : Encode categorical features
-        as a one-hot numeric array.
     """
 
     def fit(self, y):
-        """Fit label encoder
+        """Fit label encoder.
 
         Parameters
         ----------
@@ -235,25 +93,27 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
         Returns
         -------
         self : returns an instance of self.
+            Fitted label encoder.
         """
         y = column_or_1d(y, warn=True)
-        self.classes_ = _encode(y)
+        self.classes_ = _unique(y)
         return self
 
     def fit_transform(self, y):
-        """Fit label encoder and return encoded labels
+        """Fit label encoder and return encoded labels.
 
         Parameters
         ----------
-        y : array-like of shape [n_samples]
+        y : array-like of shape (n_samples,)
             Target values.
 
         Returns
         -------
-        y : array-like of shape [n_samples]
+        y : array-like of shape (n_samples,)
+            Encoded labels.
         """
         y = column_or_1d(y, warn=True)
-        self.classes_, y = _encode(y, encode=True)
+        self.classes_, y = _unique(y, return_inverse=True)
         return y
 
     def transform(self, y):
@@ -261,12 +121,13 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
 
         Parameters
         ----------
-        y : array-like of shape [n_samples]
+        y : array-like of shape (n_samples,)
             Target values.
 
         Returns
         -------
-        y : array-like of shape [n_samples]
+        y : array-like of shape (n_samples,)
+            Labels as normalized encodings.
         """
         check_is_fitted(self)
         y = column_or_1d(y, warn=True)
@@ -274,20 +135,20 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
         if _num_samples(y) == 0:
             return np.array([])
 
-        _, y = _encode(y, uniques=self.classes_, encode=True)
-        return y
+        return _encode(y, uniques=self.classes_)
 
     def inverse_transform(self, y):
         """Transform labels back to original encoding.
 
         Parameters
         ----------
-        y : numpy array of shape [n_samples]
+        y : ndarray of shape (n_samples,)
             Target values.
 
         Returns
         -------
-        y : numpy array of shape [n_samples]
+        y : ndarray of shape (n_samples,)
+            Original encoding.
         """
         check_is_fitted(self)
         y = column_or_1d(y, warn=True)
@@ -297,17 +158,16 @@ class LabelEncoder(TransformerMixin, BaseEstimator):
 
         diff = np.setdiff1d(y, np.arange(len(self.classes_)))
         if len(diff):
-            raise ValueError(
-                    "y contains previously unseen labels: %s" % str(diff))
+            raise ValueError("y contains previously unseen labels: %s" % str(diff))
         y = np.asarray(y)
         return self.classes_[y]
 
     def _more_tags(self):
-        return {'X_types': ['1dlabels']}
+        return {"X_types": ["1dlabels"]}
 
 
 class LabelBinarizer(TransformerMixin, BaseEstimator):
-    """Binarize labels in a one-vs-all fashion
+    """Binarize labels in a one-vs-all fashion.
 
     Several regression and binary classification algorithms are
     available in scikit-learn. A simple way to extend these algorithms
@@ -328,33 +188,38 @@ class LabelBinarizer(TransformerMixin, BaseEstimator):
 
     Parameters
     ----------
-
-    neg_label : int (default: 0)
+    neg_label : int, default=0
         Value with which negative labels must be encoded.
 
-    pos_label : int (default: 1)
+    pos_label : int, default=1
         Value with which positive labels must be encoded.
 
-    sparse_output : boolean (default: False)
+    sparse_output : bool, default=False
         True if the returned array from transform is desired to be in sparse
         CSR format.
 
     Attributes
     ----------
-
-    classes_ : array of shape [n_class]
+    classes_ : ndarray of shape (n_classes,)
         Holds the label for each class.
 
-    y_type_ : str,
+    y_type_ : str
         Represents the type of the target data as evaluated by
         utils.multiclass.type_of_target. Possible type are 'continuous',
         'continuous-multioutput', 'binary', 'multiclass',
         'multiclass-multioutput', 'multilabel-indicator', and 'unknown'.
 
-    sparse_input_ : boolean,
+    sparse_input_ : bool
         True if the input data to transform is given as a sparse matrix, False
         otherwise.
 
+    See Also
+    --------
+    label_binarize : Function to perform the transform operation of
+        LabelBinarizer with fixed classes.
+    OneHotEncoder : Encode categorical features using a one-hot aka one-of-K
+        scheme.
+
     Examples
     --------
     >>> from sklearn import preprocessing
@@ -388,118 +253,121 @@ class LabelBinarizer(TransformerMixin, BaseEstimator):
            [0, 1, 0],
            [0, 0, 1],
            [0, 1, 0]])
-
-    See also
-    --------
-    label_binarize : function to perform the transform operation of
-        LabelBinarizer with fixed classes.
-    sklearn.preprocessing.OneHotEncoder : encode categorical features
-        using a one-hot aka one-of-K scheme.
     """
 
-    @_deprecate_positional_args
     def __init__(self, *, neg_label=0, pos_label=1, sparse_output=False):
-        if neg_label >= pos_label:
-            raise ValueError("neg_label={0} must be strictly less than "
-                             "pos_label={1}.".format(neg_label, pos_label))
-
-        if sparse_output and (pos_label == 0 or neg_label != 0):
-            raise ValueError("Sparse binarization is only supported with non "
-                             "zero pos_label and zero neg_label, got "
-                             "pos_label={0} and neg_label={1}"
-                             "".format(pos_label, neg_label))
 
         self.neg_label = neg_label
         self.pos_label = pos_label
         self.sparse_output = sparse_output
 
     def fit(self, y):
-        """Fit label binarizer
+        """Fit label binarizer.
 
         Parameters
         ----------
-        y : array of shape [n_samples,] or [n_samples, n_classes]
+        y : ndarray of shape (n_samples,) or (n_samples, n_classes)
             Target values. The 2-d matrix should only contain 0 and 1,
             represents multilabel classification.
 
         Returns
         -------
-        self : returns an instance of self.
+        self : object
+            Returns the instance itself.
         """
-        self.y_type_ = type_of_target(y)
-        if 'multioutput' in self.y_type_:
-            raise ValueError("Multioutput target data is not supported with "
-                             "label binarization")
+
+        if self.neg_label >= self.pos_label:
+            raise ValueError(
+                f"neg_label={self.neg_label} must be strictly less than "
+                f"pos_label={self.pos_label}."
+            )
+
+        if self.sparse_output and (self.pos_label == 0 or self.neg_label != 0):
+            raise ValueError(
+                "Sparse binarization is only supported with non "
+                "zero pos_label and zero neg_label, got "
+                f"pos_label={self.pos_label} and neg_label={self.neg_label}"
+            )
+
+        self.y_type_ = type_of_target(y, input_name="y")
+
+        if "multioutput" in self.y_type_:
+            raise ValueError(
+                "Multioutput target data is not supported with label binarization"
+            )
         if _num_samples(y) == 0:
-            raise ValueError('y has 0 samples: %r' % y)
+            raise ValueError("y has 0 samples: %r" % y)
 
         self.sparse_input_ = sp.issparse(y)
         self.classes_ = unique_labels(y)
         return self
 
     def fit_transform(self, y):
-        """Fit label binarizer and transform multi-class labels to binary
-        labels.
+        """Fit label binarizer/transform multi-class labels to binary labels.
 
         The output of transform is sometimes referred to as
         the 1-of-K coding scheme.
 
         Parameters
         ----------
-        y : array or sparse matrix of shape [n_samples,] or \
-            [n_samples, n_classes]
+        y : {ndarray, sparse matrix} of shape (n_samples,) or \
+                (n_samples, n_classes)
             Target values. The 2-d matrix should only contain 0 and 1,
             represents multilabel classification. Sparse matrix can be
             CSR, CSC, COO, DOK, or LIL.
 
         Returns
         -------
-        Y : array or CSR matrix of shape [n_samples, n_classes]
-            Shape will be [n_samples, 1] for binary problems.
+        Y : {ndarray, sparse matrix} of shape (n_samples, n_classes)
+            Shape will be (n_samples, 1) for binary problems. Sparse matrix
+            will be of CSR format.
         """
         return self.fit(y).transform(y)
 
     def transform(self, y):
-        """Transform multi-class labels to binary labels
+        """Transform multi-class labels to binary labels.
 
         The output of transform is sometimes referred to by some authors as
         the 1-of-K coding scheme.
 
         Parameters
         ----------
-        y : array or sparse matrix of shape [n_samples,] or \
-            [n_samples, n_classes]
+        y : {array, sparse matrix} of shape (n_samples,) or \
+                (n_samples, n_classes)
             Target values. The 2-d matrix should only contain 0 and 1,
             represents multilabel classification. Sparse matrix can be
             CSR, CSC, COO, DOK, or LIL.
 
         Returns
         -------
-        Y : numpy array or CSR matrix of shape [n_samples, n_classes]
-            Shape will be [n_samples, 1] for binary problems.
+        Y : {ndarray, sparse matrix} of shape (n_samples, n_classes)
+            Shape will be (n_samples, 1) for binary problems. Sparse matrix
+            will be of CSR format.
         """
         check_is_fitted(self)
 
-        y_is_multilabel = type_of_target(y).startswith('multilabel')
-        if y_is_multilabel and not self.y_type_.startswith('multilabel'):
-            raise ValueError("The object was not fitted with multilabel"
-                             " input.")
+        y_is_multilabel = type_of_target(y).startswith("multilabel")
+        if y_is_multilabel and not self.y_type_.startswith("multilabel"):
+            raise ValueError("The object was not fitted with multilabel input.")
 
-        return label_binarize(y, classes=self.classes_,
-                              pos_label=self.pos_label,
-                              neg_label=self.neg_label,
-                              sparse_output=self.sparse_output)
+        return label_binarize(
+            y,
+            classes=self.classes_,
+            pos_label=self.pos_label,
+            neg_label=self.neg_label,
+            sparse_output=self.sparse_output,
+        )
 
     def inverse_transform(self, Y, threshold=None):
-        """Transform binary labels back to multi-class labels
+        """Transform binary labels back to multi-class labels.
 
         Parameters
         ----------
-        Y : numpy array or sparse matrix with shape [n_samples, n_classes]
+        Y : {ndarray, sparse matrix} of shape (n_samples, n_classes)
             Target values. All sparse matrices are converted to CSR before
             inverse transformation.
 
-        threshold : float or None
+        threshold : float, default=None
             Threshold used in the binary and multi-label cases.
 
             Use 0 when ``Y`` contains the output of decision_function
@@ -511,7 +379,8 @@ class LabelBinarizer(TransformerMixin, BaseEstimator):
 
         Returns
         -------
-        y : numpy array or CSR matrix of shape [n_samples] Target values.
+        y : {ndarray, sparse matrix} of shape (n_samples,)
+            Target values. Sparse matrix will be of CSR format.
 
         Notes
         -----
@@ -524,13 +393,14 @@ class LabelBinarizer(TransformerMixin, BaseEstimator):
         check_is_fitted(self)
 
         if threshold is None:
-            threshold = (self.pos_label + self.neg_label) / 2.
+            threshold = (self.pos_label + self.neg_label) / 2.0
 
         if self.y_type_ == "multiclass":
             y_inv = _inverse_binarize_multiclass(Y, self.classes_)
         else:
-            y_inv = _inverse_binarize_thresholding(Y, self.y_type_,
-                                                   self.classes_, threshold)
+            y_inv = _inverse_binarize_thresholding(
+                Y, self.y_type_, self.classes_, threshold
+            )
 
         if self.sparse_input_:
             y_inv = sp.csr_matrix(y_inv)
@@ -540,13 +410,11 @@ class LabelBinarizer(TransformerMixin, BaseEstimator):
         return y_inv
 
     def _more_tags(self):
-        return {'X_types': ['1dlabels']}
+        return {"X_types": ["1dlabels"]}
 
 
-@_deprecate_positional_args
-def label_binarize(y, *, classes, neg_label=0, pos_label=1,
-                   sparse_output=False):
-    """Binarize labels in a one-vs-all fashion
+def label_binarize(y, *, classes, neg_label=0, pos_label=1, sparse_output=False):
+    """Binarize labels in a one-vs-all fashion.
 
     Several regression and binary classification algorithms are
     available in scikit-learn. A simple way to extend these algorithms
@@ -561,22 +429,23 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
     y : array-like
         Sequence of integer labels or multilabel data to encode.
 
-    classes : array-like of shape [n_classes]
+    classes : array-like of shape (n_classes,)
         Uniquely holds the label for each class.
 
-    neg_label : int (default: 0)
+    neg_label : int, default=0
         Value with which negative labels must be encoded.
 
-    pos_label : int (default: 1)
+    pos_label : int, default=1
         Value with which positive labels must be encoded.
 
-    sparse_output : boolean (default: False),
-        Set to true if output binary array is desired in CSR sparse format
+    sparse_output : bool, default=False,
+        Set to true if output binary array is desired in CSR sparse format.
 
     Returns
     -------
-    Y : numpy array or CSR matrix of shape [n_samples, n_classes]
-        Shape will be [n_samples, 1] for binary problems.
+    Y : {ndarray, sparse matrix} of shape (n_samples, n_classes)
+        Shape will be (n_samples, 1) for binary problems. Sparse matrix will
+        be of CSR format.
 
     Examples
     --------
@@ -599,27 +468,34 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
            [0],
            [1]])
 
-    See also
+    See Also
     --------
-    LabelBinarizer : class used to wrap the functionality of label_binarize and
-        allow for fitting to classes independently of the transform operation
+    LabelBinarizer : Class used to wrap the functionality of label_binarize and
+        allow for fitting to classes independently of the transform operation.
     """
     if not isinstance(y, list):
         # XXX Workaround that will be removed when list of list format is
         # dropped
-        y = check_array(y, accept_sparse='csr', ensure_2d=False, dtype=None)
+        y = check_array(
+            y, input_name="y", accept_sparse="csr", ensure_2d=False, dtype=None
+        )
     else:
         if _num_samples(y) == 0:
-            raise ValueError('y has 0 samples: %r' % y)
+            raise ValueError("y has 0 samples: %r" % y)
     if neg_label >= pos_label:
-        raise ValueError("neg_label={0} must be strictly less than "
-                         "pos_label={1}.".format(neg_label, pos_label))
+        raise ValueError(
+            "neg_label={0} must be strictly less than pos_label={1}.".format(
+                neg_label, pos_label
+            )
+        )
 
-    if (sparse_output and (pos_label == 0 or neg_label != 0)):
-        raise ValueError("Sparse binarization is only supported with non "
-                         "zero pos_label and zero neg_label, got "
-                         "pos_label={0} and neg_label={1}"
-                         "".format(pos_label, neg_label))
+    if sparse_output and (pos_label == 0 or neg_label != 0):
+        raise ValueError(
+            "Sparse binarization is only supported with non "
+            "zero pos_label and zero neg_label, got "
+            "pos_label={0} and neg_label={1}"
+            "".format(pos_label, neg_label)
+        )
 
     # To account for pos_label == 0 in the dense case
     pos_switch = pos_label == 0
@@ -627,10 +503,11 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
         pos_label = -neg_label
 
     y_type = type_of_target(y)
-    if 'multioutput' in y_type:
-        raise ValueError("Multioutput target data is not supported with label "
-                         "binarization")
-    if y_type == 'unknown':
+    if "multioutput" in y_type:
+        raise ValueError(
+            "Multioutput target data is not supported with label binarization"
+        )
+    if y_type == "unknown":
         raise ValueError("The type of target data is not known")
 
     n_samples = y.shape[0] if sp.issparse(y) else len(y)
@@ -642,7 +519,7 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
             if sparse_output:
                 return sp.csr_matrix((n_samples, 1), dtype=int)
             else:
-                Y = np.zeros((len(y), 1), dtype=np.int)
+                Y = np.zeros((len(y), 1), dtype=int)
                 Y += neg_label
                 return Y
         elif len(classes) >= 3:
@@ -650,11 +527,13 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
 
     sorted_class = np.sort(classes)
     if y_type == "multilabel-indicator":
-        y_n_classes = y.shape[1] if hasattr(y, 'shape') else len(y[0])
+        y_n_classes = y.shape[1] if hasattr(y, "shape") else len(y[0])
         if classes.size != y_n_classes:
-            raise ValueError("classes {0} mismatch with the labels {1}"
-                             " found in the data"
-                             .format(classes, unique_labels(y)))
+            raise ValueError(
+                "classes {0} mismatch with the labels {1} found in the data".format(
+                    classes, unique_labels(y)
+                )
+            )
 
     if y_type in ("binary", "multiclass"):
         y = column_or_1d(y)
@@ -667,8 +546,7 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
 
         data = np.empty_like(indices)
         data.fill(pos_label)
-        Y = sp.csr_matrix((data, indices, indptr),
-                          shape=(n_samples, n_classes))
+        Y = sp.csr_matrix((data, indices, indptr), shape=(n_samples, n_classes))
     elif y_type == "multilabel-indicator":
         Y = sp.csr_matrix(y)
         if pos_label != 1:
@@ -676,8 +554,9 @@ def label_binarize(y, *, classes, neg_label=0, pos_label=1,
             data.fill(pos_label)
             Y.data = data
     else:
-        raise ValueError("%s target data is not supported with label "
-                         "binarization" % y_type)
+        raise ValueError(
+            "%s target data is not supported with label binarization" % y_type
+        )
 
     if not sparse_output:
         Y = Y.toarray()
@@ -738,10 +617,9 @@ def _inverse_binarize_multiclass(y, classes):
         y_i_argmax[np.where(row_nnz == 0)[0]] = 0
 
         # Handles rows with max of 0 that contain negative numbers
-        samples = np.arange(n_samples)[(row_nnz > 0) &
-                                       (row_max.ravel() == 0)]
+        samples = np.arange(n_samples)[(row_nnz > 0) & (row_max.ravel() == 0)]
         for i in samples:
-            ind = y.indices[y.indptr[i]:y.indptr[i + 1]]
+            ind = y.indices[y.indptr[i] : y.indptr[i + 1]]
             y_i_argmax[i] = classes[np.setdiff1d(outputs, ind)][0]
 
         return classes[y_i_argmax]
@@ -753,26 +631,26 @@ def _inverse_binarize_thresholding(y, output_type, classes, threshold):
     """Inverse label binarization transformation using thresholding."""
 
     if output_type == "binary" and y.ndim == 2 and y.shape[1] > 2:
-        raise ValueError("output_type='binary', but y.shape = {0}".
-                         format(y.shape))
+        raise ValueError("output_type='binary', but y.shape = {0}".format(y.shape))
 
     if output_type != "binary" and y.shape[1] != len(classes):
-        raise ValueError("The number of class is not equal to the number of "
-                         "dimension of y.")
+        raise ValueError(
+            "The number of class is not equal to the number of dimension of y."
+        )
 
     classes = np.asarray(classes)
 
     # Perform thresholding
     if sp.issparse(y):
         if threshold > 0:
-            if y.format not in ('csr', 'csc'):
+            if y.format not in ("csr", "csc"):
                 y = y.tocsr()
-            y.data = np.array(y.data > threshold, dtype=np.int)
+            y.data = np.array(y.data > threshold, dtype=int)
             y.eliminate_zeros()
         else:
-            y = np.array(y.toarray() > threshold, dtype=np.int)
+            y = np.array(y.toarray() > threshold, dtype=int)
     else:
-        y = np.array(y > threshold, dtype=np.int)
+        y = np.array(y > threshold, dtype=int)
 
     # Inverse transform data
     if output_type == "binary":
@@ -794,7 +672,7 @@ def _inverse_binarize_thresholding(y, output_type, classes, threshold):
 
 
 class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
-    """Transform between iterable of iterables and a multilabel format
+    """Transform between iterable of iterables and a multilabel format.
 
     Although a list of sets or tuples is a very intuitive format for multilabel
     data, it is unwieldy to process. This transformer converts between this
@@ -803,18 +681,24 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
 
     Parameters
     ----------
-    classes : array-like of shape [n_classes] (optional)
+    classes : array-like of shape (n_classes,), default=None
         Indicates an ordering for the class labels.
         All entries should be unique (cannot contain duplicate classes).
 
-    sparse_output : boolean (default: False),
-        Set to true if output binary array is desired in CSR sparse format
+    sparse_output : bool, default=False
+        Set to True if output binary array is desired in CSR sparse format.
 
     Attributes
     ----------
-    classes_ : array of labels
-        A copy of the `classes` parameter where provided,
-        or otherwise, the sorted set of classes found when fitting.
+    classes_ : ndarray of shape (n_classes,)
+        A copy of the `classes` parameter when provided.
+        Otherwise it corresponds to the sorted set of classes found
+        when fitting.
+
+    See Also
+    --------
+    OneHotEncoder : Encode categorical features using a one-hot aka one-of-K
+        scheme.
 
     Examples
     --------
@@ -848,20 +732,14 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
     MultiLabelBinarizer()
     >>> mlb.classes_
     array(['comedy', 'sci-fi', 'thriller'], dtype=object)
-
-    See also
-    --------
-    sklearn.preprocessing.OneHotEncoder : encode categorical features
-        using a one-hot aka one-of-K scheme.
     """
 
-    @_deprecate_positional_args
     def __init__(self, *, classes=None, sparse_output=False):
         self.classes = classes
         self.sparse_output = sparse_output
 
     def fit(self, y):
-        """Fit the label sets binarizer, storing :term:`classes_`
+        """Fit the label sets binarizer, storing :term:`classes_`.
 
         Parameters
         ----------
@@ -872,24 +750,27 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
 
         Returns
         -------
-        self : returns this MultiLabelBinarizer instance
+        self : object
+            Fitted estimator.
         """
         self._cached_dict = None
         if self.classes is None:
             classes = sorted(set(itertools.chain.from_iterable(y)))
         elif len(set(self.classes)) < len(self.classes):
-            raise ValueError("The classes argument contains duplicate "
-                             "classes. Remove these duplicates before passing "
-                             "them to MultiLabelBinarizer.")
+            raise ValueError(
+                "The classes argument contains duplicate "
+                "classes. Remove these duplicates before passing "
+                "them to MultiLabelBinarizer."
+            )
         else:
             classes = self.classes
-        dtype = np.int if all(isinstance(c, int) for c in classes) else object
+        dtype = int if all(isinstance(c, int) for c in classes) else object
         self.classes_ = np.empty(len(classes), dtype=dtype)
         self.classes_[:] = classes
         return self
 
     def fit_transform(self, y):
-        """Fit the label sets binarizer and transform the given label sets
+        """Fit the label sets binarizer and transform the given label sets.
 
         Parameters
         ----------
@@ -900,9 +781,10 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
 
         Returns
         -------
-        y_indicator : array or CSR matrix, shape (n_samples, n_classes)
-            A matrix such that `y_indicator[i, j] = 1` iff `classes_[j]` is in
-            `y[i]`, and 0 otherwise.
+        y_indicator : {ndarray, sparse matrix} of shape (n_samples, n_classes)
+            A matrix such that `y_indicator[i, j] = 1` iff `classes_[j]`
+            is in `y[i]`, and 0 otherwise. Sparse matrix will be of CSR
+            format.
         """
         self._cached_dict = None
 
@@ -918,13 +800,12 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
         tmp = sorted(class_mapping, key=class_mapping.get)
 
         # (make safe for tuples)
-        dtype = np.int if all(isinstance(c, int) for c in tmp) else object
+        dtype = int if all(isinstance(c, int) for c in tmp) else object
         class_mapping = np.empty(len(tmp), dtype=dtype)
         class_mapping[:] = tmp
         self.classes_, inverse = np.unique(class_mapping, return_inverse=True)
         # ensure yt.indices keeps its current dtype
-        yt.indices = np.array(inverse[yt.indices], dtype=yt.indices.dtype,
-                              copy=False)
+        yt.indices = np.array(inverse[yt.indices], dtype=yt.indices.dtype, copy=False)
 
         if not self.sparse_output:
             yt = yt.toarray()
@@ -932,7 +813,7 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
         return yt
 
     def transform(self, y):
-        """Transform the given label sets
+        """Transform the given label sets.
 
         Parameters
         ----------
@@ -959,27 +840,30 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
 
     def _build_cache(self):
         if self._cached_dict is None:
-            self._cached_dict = dict(zip(self.classes_,
-                                         range(len(self.classes_))))
+            self._cached_dict = dict(zip(self.classes_, range(len(self.classes_))))
 
         return self._cached_dict
 
     def _transform(self, y, class_mapping):
-        """Transforms the label sets with a given mapping
+        """Transforms the label sets with a given mapping.
 
         Parameters
         ----------
         y : iterable of iterables
+            A set of labels (any orderable and hashable object) for each
+            sample. If the `classes` parameter is set, `y` will not be
+            iterated.
+
         class_mapping : Mapping
-            Maps from label to column index in label indicator matrix
+            Maps from label to column index in label indicator matrix.
 
         Returns
         -------
-        y_indicator : sparse CSR matrix, shape (n_samples, n_classes)
-            Label indicator matrix
+        y_indicator : sparse matrix of shape (n_samples, n_classes)
+            Label indicator matrix. Will be of CSR format.
         """
-        indices = array.array('i')
-        indptr = array.array('i', [0])
+        indices = array.array("i")
+        indptr = array.array("i", [0])
         unknown = set()
         for labels in y:
             index = set()
@@ -991,19 +875,21 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
             indices.extend(index)
             indptr.append(len(indices))
         if unknown:
-            warnings.warn('unknown class(es) {0} will be ignored'
-                          .format(sorted(unknown, key=str)))
+            warnings.warn(
+                "unknown class(es) {0} will be ignored".format(sorted(unknown, key=str))
+            )
         data = np.ones(len(indices), dtype=int)
 
-        return sp.csr_matrix((data, indices, indptr),
-                             shape=(len(indptr) - 1, len(class_mapping)))
+        return sp.csr_matrix(
+            (data, indices, indptr), shape=(len(indptr) - 1, len(class_mapping))
+        )
 
     def inverse_transform(self, yt):
-        """Transform the given indicator matrix into label sets
+        """Transform the given indicator matrix into label sets.
 
         Parameters
         ----------
-        yt : array or sparse matrix of shape (n_samples, n_classes)
+        yt : {ndarray, sparse matrix} of shape (n_samples, n_classes)
             A matrix containing only 1s ands 0s.
 
         Returns
@@ -1015,22 +901,29 @@ class MultiLabelBinarizer(TransformerMixin, BaseEstimator):
         check_is_fitted(self)
 
         if yt.shape[1] != len(self.classes_):
-            raise ValueError('Expected indicator for {0} classes, but got {1}'
-                             .format(len(self.classes_), yt.shape[1]))
+            raise ValueError(
+                "Expected indicator for {0} classes, but got {1}".format(
+                    len(self.classes_), yt.shape[1]
+                )
+            )
 
         if sp.issparse(yt):
             yt = yt.tocsr()
             if len(yt.data) != 0 and len(np.setdiff1d(yt.data, [0, 1])) > 0:
-                raise ValueError('Expected only 0s and 1s in label indicator.')
-            return [tuple(self.classes_.take(yt.indices[start:end]))
-                    for start, end in zip(yt.indptr[:-1], yt.indptr[1:])]
+                raise ValueError("Expected only 0s and 1s in label indicator.")
+            return [
+                tuple(self.classes_.take(yt.indices[start:end]))
+                for start, end in zip(yt.indptr[:-1], yt.indptr[1:])
+            ]
         else:
             unexpected = np.setdiff1d(yt, [0, 1])
             if len(unexpected) > 0:
-                raise ValueError('Expected only 0s and 1s in label indicator. '
-                                 'Also got {0}'.format(unexpected))
-            return [tuple(self.classes_.compress(indicators)) for indicators
-                    in yt]
+                raise ValueError(
+                    "Expected only 0s and 1s in label indicator. Also got {0}".format(
+                        unexpected
+                    )
+                )
+            return [tuple(self.classes_.compress(indicators)) for indicators in yt]
 
     def _more_tags(self):
-        return {'X_types': ['2dlabels']}
+        return {"X_types": ["2dlabels"]}
